ImageSoftware — MSUMastro toolbox 0.1 documentation

# ImageSoftware

class `msumastro.header_processing.feder.` `ImageSoftware`(name, fits_name=None, major_version=None, minor_version=None, bad_keywords=None, fits_keyword=None, purged_flag_keyword=None)

  Bases: `object`

  Represents software that takes images at telescope.

  Parameters: | name : str Name of the software. Can be the same is the name in the FITS file, or not. fits_keyword : str Name of the FITS keyword that contains the name of the software. fits_name : list of str Name of the software as written in the FITS file major_version : int Major version number of the software. minor_version : int Minor version number of the software. bad_keywords : list of strings Names of any keywords that should be removed from the FITS before further processing. purged_flag_keyword : str, optional Name of the keyword which indicates whether bad keywords have already been purged. Default value is ‘PURGED’

  Methods Summary

  `created_this`(version_string) | Indicate whether version string matches this software :Parameters: version_string : str String from FITS header that indicates software version.

  Methods Documentation

  `created_this`(version_string)

    Indicate whether version string matches this software

    Parameters: | version_string : str String from FITS header that indicates software version.
    Returns: | bool `True` if the version string matches the software instance.